# deres

[![Tests][badge-tests]][tests]
[![Documentation][badge-docs]][documentation]

[badge-tests]: https://img.shields.io/github/actions/workflow/status/scverse/deres/test.yaml?branch=main
[badge-docs]: https://img.shields.io/readthedocs/deres

Container and visualization functions for differential expression (and similar) result tables.

## Getting started

Please refer to the [documentation][],
in particular, the [API documentation][].

## Installation

You need to have Python 3.10 or newer installed on your system.
If you don't have Python installed, we recommend installing [uv][].

There are several alternative options to install deres:

<!--
1) Install the latest release of `deres` from [PyPI][]:

```bash
pip install deres
```
-->

1. Install the latest development version:

```bash
pip install git+https://github.com/scverse/deres.git@main
```

## Release notes

See the [changelog][].

## Contact

For questions and help requests, you can reach out in the [scverse discourse][].
If you found a bug, please use the [issue tracker][].

## Citation

> t.b.a

[uv]: https://github.com/astral-sh/uv
[scverse discourse]: https://discourse.scverse.org/
[issue tracker]: https://github.com/scverse/deres/issues
[tests]: https://github.com/scverse/deres/actions/workflows/test.yaml
[documentation]: https://deres.readthedocs.io
[changelog]: https://deres.readthedocs.io/en/latest/changelog.html
[api documentation]: https://deres.readthedocs.io/en/latest/api.html
[pypi]: https://pypi.org/project/deres
